var servers = {};
//Streaming mode
servers.StreamingModes = {
	"HTTPLIVE":1,
	"RTP":2,
	"RTMP":3,
	"RTP_RTMP":4,
	"JPEG":5
};

/*servers.NUM_STREAMS = 2;

servers.STREAMS = {
	"LOCAL" : 0,
	"REMOTE" : 1
};*/

servers.STREAM_WIDTH_X_HEIGHT = new Array({width:"320",height:"240"}, {width:"640",height:"480"}, {width:"1280",height:"720"}, {width:"1920",height:"1080"}, {width:"240",height:"160"}); // 854 x 480

servers.ResponseCodes = {
	"SUCCESS" : 0,
	"UNSUPPORTED_HTTP_METHOD" : 1,
	"UNSUPPORTED_RETURN_TYPE" : 2,
	"UNSUPPORTED_ATTRIBUTE" : 3,
	"UNKNOWN_ATTRIBUTE" : 4,
	"UNKNOWN_PROPERTY" : 5,
	"MESSAGE_PARSE_ERROR" : 6,
	"DATABASE_FAILURE" : 7,
	"UNKNOWN_ERROR" : 8,
	"INVALID_STREAMING_MODE" : 9,
	"FAILED_TO_RESTART_STREAMING" : 10
};

servers.ResponseStrings = ["Success",
                         "Incorrect http method for this resource",
                         "Unsupported return mime-type",
                         "Unsupported attribute encountered for this resource",
                         "Unknown attribute encountered for this resource",
                         "Unknown property encountered for this resource",
                         "Message parsing error",
                         "Database IO error",
                         "An unknown error was encountered",
                         "Invalid streaming mode",
                         "Failed to restart streaming."];

servers.get = function() {
	$.ajax({
		beforeSend: function(xhrObj){
			xhrObj.setRequestHeader("Accept","application/xml");
		},
		url: "/cgi-bin/v1/servers?"+Math.random(),
		async: false,
		type: "GET",
		dataType: "xml",
		success: getSuccessHandler,
		error: function(err, textStatus) {
			handleError("/servers", "GET", err, textStatus);
		}
	});
	
	function getSuccessHandler (result) {
		var serverNode = $(result).children("servers");
		var smodeNode = $(serverNode).children("smode");
		var sformatNode = $(serverNode).children("sformat");

		if (smodeNode == undefined || smodeNode.attr("ul") == undefined) {
			alert("<smode ul=\"\"/> node is missing");
			currentStreamingMode = servers.StreamingModes.RTP;
			return;
		} else {
			currentStreamingMode = parseInt( smodeNode.attr("ul") );
		}
	}
};

servers.put = function () {
	var newStreamingMode;
	
	// First check if the user has changed the streaming mode/format
	if (parseInt($("input:radio[name=radio_streaming]:checked").val()) == currentStreamingMode) {
		alert("Streaming mode is already set to "+$("input:radio[name=radio_streaming]:checked").attr("stream"));
		return;
	}
	
	function serializeXML () {
		var smode = $("input:radio[name=radio_streaming]:checked").val();
		newStreamingMode = parseInt(smode);

		var xml = '<?xml version="1.0"?>';
		xml += '<servers>';
		xml += '<smode ul="'+smode+'"/>';
		xml += '</servers>';
		return xml;
	}
	
	var xml = serializeXML();
	
	$.ajax({
		beforeSend: function(xhrObj){
			xhrObj.setRequestHeader("Accept","application/xml");
			xhrObj.setRequestHeader("Content-Type","application/xml");
			$("#button_apply").attr("disabled",true);
			$("#statusTxt").html("Updating settings...");
		    $("#spanLoader").css({visibility:"visible"});
		},
		url: "/cgi-bin/v1/servers",
		type: "PUT",
		data: xml,
		dataType: "xml",
		success: putSuccessHandler,
		error: function(err, textStatus) {
			$("#spanLoader").css({visibility:"hidden"});
			$("#button_apply").attr("disabled",false);
			handleError("/servers", "PUT", err, textStatus);
		}
	});
	
	function putSuccessHandler (result) {

		// Check success
		var serverNode = $(result).children("servers");
		var res = $(serverNode).children("res").attr("ul");
		if( res != 0 ) {
			alert("Error! " + servers.ResponseStrings[parseInt(res)]);
			$("#button_apply").attr("disabled",false);
			$("#spanLoader").css({visibility:"hidden"});
			return;
		}

		// Update the new streaming mode
		currentStreamingMode = newStreamingMode;
		
		cameraStatus.cameraOnHandler = servers.cameraOn;
		$("#statusTxt").html("Please wait while your video streaming restarts...");
		//statusTimer = window.setTimeout(cameraStatus.get, 2000);
	}
};

servers.cameraOn = function () {
	$("#button_apply").attr("disabled",false);
	$("#spanLoader").css({visibility:"hidden"});
	alert("Streaming restarted!");
};

servers.getIP = function(hostname) {
	var ip = "none";
	
	var cgiPath;
	if( location.port && location.port != 80 ) {
		// remote access
		cgiPath = "/cgi-bin/getipr?"+hostname;
	} else {
		// local access
		cgiPath = "/cgi-bin/getipl";
	}

	$.ajax({
		url: cgiPath,
		type: "GET",
		async: false,
		success: successHandler,
		error: function(err) {
			alert( "Error: "+err.status );
		}
	});
	
	function successHandler( result ) {
		//alert("in success : "+result);
		ip = result;
	}
	
	return ip;
};

servers.setValues = function() {
	if (currentStreamingMode == servers.StreamingModes.RTP || currentStreamingMode == servers.StreamingModes.RTMP) {
		$("#rtpRtmpControl").show();
		$("#httpliveControl").show();
		$("input:radio[name=radio_streaming]").val([currentStreamingMode+""]);
	} else if (currentStreamingMode == servers.StreamingModes.RTP_RTMP) {
		// Both RTSP (with HTTPLIVE) and RTMP streaming are enabled
		$("#rtpRtmpControl").html("RTSP and RTMP streaming modes are enabled");
		$("#rtpRtmpControl").show();
		$("#httpliveControl").hide();
	}
};
